@@ -114,6 +114,7 @@ static void cb_m_tag (GtkCheckMenuItem *widget, Dialog *d);
 static void cb_b_info (GtkToggleButton *tb, Dialog *d);
 static void toggle_ui_info (Dialog *d, gboolean active);
 static void toggle_ui_flip (Dialog *d, gboolean active);
+static void update_title (void);
 
 
 static Dialog *dialog = NULL;
@@ -682,6 +683,8 @@ dialog_blank (void)
     display_text (dialog->textbuf[FRONT], NULL);
     gtk_notebook_set_current_page (dialog->notebook, FRONT);
     set_interface_sensitivity (dialog);
+
+    update_title ();
 }
 
 
@@ -725,6 +728,8 @@ show_current_card (Dialog *d)
     gtk_check_menu_item_set_active (d->m_tag, card_get_tagged (c));
     g_signal_handlers_unblock_by_func (G_OBJECT(d->m_tag),
         G_CALLBACK(cb_m_tag), d);
+
+    update_title ();
 }
 
 
@@ -1072,6 +1077,8 @@ cb_m_tag (GtkCheckMenuItem *widget, Dialog *d)
         app_window_refresh_card_row (d->ig, item);
         app_window_update_title (d->ig);
     }
+
+    update_title ();
 }
 
 
@@ -1302,6 +1309,35 @@ dialog_editor_preferences_changed (void)
 }
 
 
+static void
+update_title (void)
+{
+    GList *item;
+    Card *c;
+    gchar *title, *flag = "";
+
+    if (!dialog) { return; }
+
+    item = file_get_current_item (dialog->ig->file);
+
+    if (item != NULL) {
+
+        c = CARD(item);
+        g_assert (c != NULL);
+
+        if (card_get_tagged (c)) {
+          flag = UNICHAR_TAGGED;
+        }
+    }
+
+    title = g_strdup_printf (_("Card Editor %s"), flag);
+
+    gtk_window_set_title (GTK_WINDOW(dialog->window), title);
+
+    g_free (title);
+}
+
+
 void
 dialog_editor (Ignuit *ig)
 {
