@@ -112,6 +112,7 @@ static void toggle_ui_known (Dialog *d, gboolean active);
 static void toggle_ui_unknown (Dialog *d, gboolean active);
 static void toggle_ui_info (Dialog *d, gboolean active);
 static void toggle_ui_flip (Dialog *d, gboolean active);
+static void update_title (void);
 
 
 static Dialog *dialog = NULL;
@@ -697,6 +698,8 @@ cb_m_tag (GtkCheckMenuItem *widget, Dialog *d)
 
         app_window_update_title (d->ig);
     }
+
+    update_title ();
 }
 
 
@@ -891,6 +894,31 @@ toggle_ui_flip (Dialog *d, gboolean active)
 }
 
 
+static void
+update_title (void)
+{
+    Card *c;
+    gchar *title, *flag = "";
+
+    if (!dialog) { return; }
+
+    c = QCARD(dialog->cur);
+
+    if (!CUR_IS_LAST(dialog)) {
+
+        if (card_get_tagged (c)) {
+          flag = UNICHAR_TAGGED;
+        }
+    }
+
+    title = g_strdup_printf (_("Quiz %s"), flag);
+
+    gtk_window_set_title (GTK_WINDOW(dialog->window), title);
+
+    g_free (title);
+}
+
+
 void
 dialog_quiz (Ignuit *ig)
 {
