@@ -46,6 +46,9 @@
 #define F_IMG_BTN_QUIZ_1        PACKAGE G_DIR_SEPARATOR_S \
                                 "box-start-quiz-24.png"
 
+#define UNICHAR_TAGGED    "\342\232\221"  /* UTF-8 Black Flag */
+#define UNICHAR_EXPIRED   "\342\230\205"  /* UTF-8 Black Star */
+
 
 enum {
     FRONT = 0,
